#
# spec file for package python-nose2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-nose2
Version:        0.12.0
Release:        2.3
Summary:        The successor to the Python testing framework nose, based on unittest
License:        BSD-2-Clause AND Python-2.0
URL:            https://github.com/nose-devs/nose2
Source:         https://files.pythonhosted.org/packages/source/n/nose2/nose2-%{version}.tar.gz
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Suggests:       python-coverage
BuildArch:      noarch
%python_subpackages

%description
nose2 is the successor to nose. It's unittest with plugins.
nose2 is a new project and does not support all of the behaviors of nose.
nose2's purpose is to extend unittest to make testing nicer and easier to understand.

%prep
%setup -q -n nose2-%{version}

%build
%pyproject_wheel

%install
# -I : work around boo#1201041
%pyproject_install -I
%python_clone -a %{buildroot}%{_bindir}/nose2
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LC_CTYPE=C.UTF8
%{python_expand # nose must test itself in an editable install
$python -m venv editable-%{$python_bin_suffix} --system-site-packages
. editable-%{$python_bin_suffix}/bin/activate
pip install -e .
nose2 -v --pretty-assert
deactivate
}

%post
%python_install_alternative nose2

%postun
%python_uninstall_alternative nose2

%files %{python_files}
%license license.txt
%doc AUTHORS README.rst
%python_alternative %{_bindir}/nose2
%{python_sitelib}/nose2
%{python_sitelib}/nose2-%{version}*-info

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Aug 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.12.0
  * Note: The 0.12.x series will be the final releases of nose2
    which support Python 2.
  * Passing --junit-xml-path now implies --junit-xml when using the
    junitxml plugin. This means that the --junit-xml flag can be
    omitted when --junit-xml-path is specified. (:issue:`521`)
  * Remove the dependency on coverage. Use of the coverage plugin
    now requires that you either install coverage independently, or
    use the extra, nose2[coverage_plugin]. As a result, nose2 no
    longer has any strict dependencies
  * Remove the dependency on six, instead using a vendored copy.
    This ensures that the dependency for nose2 doesn't conflict
    with application dependencies
  * nose2 no longer provides an entry-point named based on the
    current python version, e.g. nose2-3.8 on python3.8 . Only the
    nose2 command is provided.
  * Remove support for setup.py test on nose2 itself. This usage is
    deprecated by setuptools. Developers contributing to nose2 are
    encouraged to use tox to run nose2's testsuite, per the
    contributing guide.
- Release 0.11.0
  * Test classes now have their short description (first line of
    docstring) printed in verbose output
  * The junitxml plugin now sets timestamp on each testcase node as
    an ISO-8601 timestamp. Thanks to :user:`deeplow` for the
    contribution!
  * Drop support for Python 3.5
  * Python 3.10 is now officially supported. Python 3.11-dev will
    be supported on a best-effort basis. Thanks to :user:`hugovk`
    and :user:`tirkarthi` for their contributions!
  * Add support for test classes when running with the
    multiprocessing plugin. Thanks to :user:`ltfish` for the
    initial contribution and :user:`stefanholek` for the refinement
    to this change!
- Release 0.10.0
  * Support for subtests!
  * Notes for plugin authors about subtest support:
  - Subtest failures will produce a TestOutcomeEvent with outcome
    = "subtest"
  - Subtest events can be failures, but they do not indicate
    success -- the containing test will send a success event if
    no subtests fail
  * Drop support for Python 3.4
  * Python 3.8 and 3.9 are now officially supported
  * Improve helptext for the multiprocess plugin's -N option
  * When run with reduced verbosity (e.g. with -q), nose2 will no
    longer print an empty line before test reports
  * The plugin registry will no longer contain duplicate plugins
    and or base event.Plugin instances
  * Fix function test case implementation of id, __str__, and
    __repr__. This removes the injected transplant_class.<locals>
    from reporting output
  * Doctest loading will now skip setup.py files in the project
    root
  * Class methods decorated (e.g. with mock.patch) are no longer
    incorrectly picked up by the function loader
- Drop patches
  * remove_unittest2.patch
  * ignore-warnings-doctests.patch
  * fix-mock-dep.patch
* Wed May  4 2022 pgajdos@suse.com
- python-mock is not required for build
* Thu Oct  7 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Mon Mar  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.2:
  * Add --junit-xml-path to the junit plugin argument list
  * It is now possible to use the multiprocess and coverage plugins together, as long as all of the coverage config is put into the config file
  * Minor changes to be compatible with newer pythons (3.8, 3.9)
* Mon Nov 11 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add ignore-warnings-doctests.patch to supress warnings when running
  doctests.
* Mon Sep 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add dep on coverage as it is hard requirement based on requires
* Tue May 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new mock versions:
  * fix-mock-dep.patch
* Mon Apr  8 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.9.1
- refresh remove_unittest2.patch
  * the prof plugin now uses cProfile instead of hotshot for profiling
  * skipped tests now include the user's reason in junit XML's message field
  * the prettyassert plugin mishandled multi-line function definitions
  * Using a plugin's CLI flag when the plugin is already enabled via config
  no longer errors
  * nose2.plugins.prettyassert, enabled with --pretty-assert
  * Cleanup code for EOLed python versions
  * Dropped support for distutils.
  * Result reporter respects failure status set by other plugins
  * JUnit XML plugin now includes the skip reason in its output
* Thu Aug 16 2018 jengelh@inai.de
- Avoid name repetition in summary (rpmlint).
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
  Add remove_unittest2.patch to faciliate that
- Upgrade to 0.8.0:
    List of changes is too long to show here, see
    https://github.com/nose-devs/nose2/blob/master/docs/changelog.rst
    changes between 0.6.5 and 0.8.0
* Wed Jun 28 2017 jengelh@inai.de
- Update package description
* Mon Apr 24 2017 alarrosa@suse.com
- Use singlespec macros
* Mon Feb  6 2017 alarrosa@suse.com
- Initial release
